@@ -101,12 +101,6 @@ class TuyaDeviceManager:
 
     """
 
-    deviceMap: Dict[str, TuyaDevice] = {}
-
-    categoryFunctionMap: Dict[str, TuyaDeviceFunction] = {}
-
-    device_listeners = set()
-
     def __init__(self, 
         api: TuyaOpenAPI, 
         mq: TuyaOpenMQ):
@@ -115,6 +109,9 @@ class TuyaDeviceManager:
         self.device_manage = SmartHomeDeviceManage(api) if (api.project_type == ProjectType.SMART_HOME) else IndustrySolutionDeviceManage(api)
 
         mq.add_message_listener(self._onMessage)
+        self.deviceMap: Dict[str, TuyaDevice] = {}
+        self.device_listeners = set()
+
 
     def __del__(self):
         self.mq.remove_message_listener(self._onMessage)
